pub struct Keys { /* private fields */ }Expand description
Represents Kyber key pair.
Implementations
Sourceimpl Keys
impl Keys
Sourcepub fn new() -> Result<Keys, JsError>
pub fn new() -> Result<Keys, JsError>
Create a new key pair.
This function generates a new Kyber key pair and returns it as a Keys struct.
Errors
Returns a JsError if an error occurs during key pair generation.